netapp_ontap.models.data_engine_sub_job API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_sub_job`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineSubJobSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineSubJob object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `create_time: ImpreciseDateTime GET`

    The creation time of the job.

    Example: 2018-06-04T19:00:00.000+0000

  `description: str GET`

    The description of the job.

    Example: Workspace Create Job

  `end_time: ImpreciseDateTime GET`

    The end time of the job.

    Example: 2018-06-04T19:00:00.000+0000

  `error: DcnCommonError GET`

    DCN ONTAP related error information.

  `links: SelfLink GET`

    The links field of the data_engine_sub_job.

  `name: str GET`

    The name of the job.

    Example: workspace create

  `parent_job: DataEngineJobParentJob GET`

    The parent job reference of the job.

  `percent_complete: Size GET`

    The percentage of the job that is completed.

    Example: 5

  `start_time: ImpreciseDateTime GET`

    The start time of the job.

    Example: 2018-06-04T19:00:00.000+0000

  `state: str GET`

    The state of the data engine job:

    - queued - The job is queued for execution.
    - running - The job is currently in execution.
    - success - The job has been completed successfully.
    - failure - The job has failed.

    Valid choices:

    - queued
    - running
    - success
    - failure
  `tags: List[str] GET`

    Job tags in string format.

  `timeout: Size GET`

    The timeout period of the job in minutes.

    Example: 30

  `type: str GET`

    The type of the job.

    Valid choices:

    - workspace_create
    - workspace_update
    - workspace_delete
    - workspace_refresh
    - workspace_content_processing
    - workspace_versioning
    - data_collection_update
    - data_collection_delete
    - data_collection_refresh
    - data_collection_content_processing
    - data_source_create
    - data_source_update
    - data_source_delete
    - data_source_refresh
    - policy_enforcement
    - cleanup
    - entity_preview
    - entity_cache_cleanup
    - workspace_version_diff
    - data_collection_version_diff
  `update_time: ImpreciseDateTime GET`

    The update time of the job.

    Example: 2018-06-04T19:00:00.000+0000

  `uuid: str GET`

    The unique identifier of the job.

    Example: 123e4567-e89b-12d3-a456-426614174000